==> fapman_0.5.2-1.tar.gz: fapman-0.5.2/settings.h <==
/*
	This file is part of Faster Application Manager.

	Faster Application Manager is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Faster Application Manager is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Faster Application Manager.  If not, see <http://www.gnu.org/licenses/>.

	(C) Heikki Holstila 2010
*/

#ifndef SETTINGS_H
#define SETTINGS_H

#include <QtGui>

class AAptInterface;

namespace Ui {
    class Settings;
}

class Settings : public QDialog
{
    Q_OBJECT

public:
    explicit Settings(QWidget *parent = 0);
    ~Settings();
	void openWin();
	void setAptInterface(AAptInterface* apt) { iAptInterface=apt; }

#ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
	void open() {
		QRect r = dynamic_cast<QWidget*>(this->parent())->rect();
		if(r.width() < r.height())
			this->setAttribute(Qt::WA_Maemo5PortraitOrientation);
		else {
			if( dynamic_cast<QWidget*>(this->parent())->testAttribute( Qt::WA_Maemo5AutoOrientation ) )
				this->setAttribute( Qt::WA_Maemo5AutoOrientation );
			else
				this->setAttribute( Qt::WA_Maemo5LandscapeOrientation );
		}
		QDialog::open();
	}
#endif

	QSettings* qsettings() { return iQSettings; }

protected:
    void changeEvent(QEvent *e);

private:
    Ui::Settings *ui;
	QSettings* iQSettings;
	AAptInterface* iAptInterface;

private slots:
	void on_btn_OK_clicked();
};

#endif // SETTINGS_H

==> fapman_0.6.1-1.tar.gz: fapman-0.6.1/settings.h <==
/*
	This file is part of Faster Application Manager.

	Faster Application Manager is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Faster Application Manager is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Faster Application Manager.  If not, see <http://www.gnu.org/licenses/>.

	(C) Heikki Holstila 2010
*/

#ifndef SETTINGS_H
#define SETTINGS_H

#include <QtGui>

class AAptInterface;
class PackageView;

namespace Ui {
    class Settings;
}

class Settings : public QDialog
{
    Q_OBJECT

public:
    explicit Settings(QWidget *parent = 0);
    ~Settings();
	void openWin();
	void setAptInterface(AAptInterface* apt) { iAptInterface=apt; }
	void setPackageView(PackageView* v_) { iPackageView=v_; }

#ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
	void open() {
		QRect r = dynamic_cast<QWidget*>(this->parent())->rect();
		if(r.width() < r.height())
			this->setAttribute(Qt::WA_Maemo5PortraitOrientation);
		else {
			if( dynamic_cast<QWidget*>(this->parent())->testAttribute( Qt::WA_Maemo5AutoOrientation ) )
				this->setAttribute( Qt::WA_Maemo5AutoOrientation );
			else
				this->setAttribute( Qt::WA_Maemo5LandscapeOrientation );
		}
		QDialog::open();
	}
#endif

	QSettings* qsettings() { return iQSettings; }

protected:
    void changeEvent(QEvent *e);

private:
    Ui::Settings *ui;
	QSettings* iQSettings;
	AAptInterface* iAptInterface;
	PackageView* iPackageView;

private slots:
	void on_pushButton_searchOptions_clicked();
 void on_pushButton_picksound_clicked();
 void on_btn_OK_clicked();
};

#endif // SETTINGS_H
